==> csvjson-jsoncsv-cg-lib-1.0.11.tgz: package/lib/transforms.js <==
const {constants, helpers} = require('utils-nxg-cg');
const converter = require('json-2-csv');
const os = require('os');
const eol = require('eol')
const {convertToUtf8} = require('utils-nxg-cg/utils/helpers');

/**
 * Method to transform a json to csv file
 * @param properties
 * @returns {Promise<string>}
 */
const transformJsonToCSV = async (properties) => {
    try {
        const options = {
            delimiter: {
                field: properties.delimiter // custom field delimiter
            },
            prependHeader: true,
            sortHeader: false,
            excelBOM: false,
            trimHeaderValues: true,
            trimFieldValues: true
        };

        let bodyJson = properties.content;
        if (!Array.isArray(properties.content) && !helpers.isObjectValid(properties.content)) {
            if (helpers.validateBase64(properties.content)) {
                // log.debug('content is base64');
                bodyJson = JSON.parse(helpers.convertBase64ToUtf8(properties.content));
            } else {
                // log.debug('content is a string object');
                bodyJson = JSON.parse(properties.content);
            }
        }
        //result as base64
        return Buffer.from(await converter.json2csvAsync(JSON.parse(bodyJson), options)).toString('base64');
    } catch (e) {
        throw Error(e);
    }
};

/**
 * Method to transform csv files to json output
 * @param properties
 * @returns {Promise<*[]|any>}
 */
const transformCsvToJson = async (properties) => {
    try {
        const options = {
            delimiter: {
                field: properties.delimiter,
                eol: os.EOL
            },
            trimHeaderFields : true,
            trimFieldValues  : true,
        };
        const csv_data = eol.auto(helpers.convertToUtf8(properties.content));
        if (properties.headers) {
            const result = JSON.parse(JSON.stringify(await converter.csv2jsonAsync(csv_data, options)));
            if(helpers.isObjectValid(result))
                return result;
            else
                throw Error(constants.ERROR_JSON_FORMAT);
        } else {
            const regex = new RegExp(`${properties.delimiter}(?=(?:[^\\"]*\\"[^\\"]*\\")*[^\\"]*$)`);
            const array = csv_data.toString().split(os.EOL);
            const customHeaders = [];
            let numHeaders = array[0].split(regex);
            for (let h in numHeaders) {
                customHeaders.push(`element ${Number.parseInt(h) + 1}`);
            }
            const csvToJsonResult = [];
            for (let i = 0; i < array.length; i++) {
                let obj = {};
                let currentLine = array[i].split(regex);
                for (let j = 0; j < customHeaders.length; j++) {
                    obj[customHeaders[j]] = currentLine[j];
                }
                csvToJsonResult.push(obj);
            }
            const result = JSON.parse(JSON.stringify(csvToJsonResult));
            if(helpers.isObjectValid(result))
                return result;
            else
                throw Error(constants.ERROR_JSON_FORMAT);
        }
    } catch (e) {
        throw Error(e);
    }
};

module.exports = {transformCsvToJson, transformJsonToCSV};

==> csvjson-jsoncsv-cg-lib-1.0.13.tgz: package/lib/transforms.js <==
const {constants, helpers} = require('utils-nxg-cg');
const converter = require('json-2-csv');
const os = require('os');
const eol = require('eol')
const {convertToObject} = require('utils-nxg-cg/utils/helpers');

/**
 * Method to transform a json to csv file
 * @param properties
 * @returns {Promise<string>}
 */
const transformJsonToCSV = async (properties) => {
    try {
        const options = {
            delimiter: {
                field: properties.delimiter // custom field delimiter
            },
            prependHeader: true,
            sortHeader: false,
            excelBOM: false,
            trimHeaderValues: true,
            trimFieldValues: true
        };

        let bodyJson = convertToObject(properties.content);

        //result as base64
        return Buffer.from(await converter.json2csvAsync(bodyJson, options)).toString('base64');
    } catch (e) {
        throw Error(e);
    }
};

/**
 * Method to transform csv files to json output
 * @param properties
 * @returns {Promise<*[]|any>}
 */
const transformCsvToJson = async (properties) => {
    try {
        const options = {
            delimiter: {
                field: properties.delimiter,
                eol: os.EOL
            },
            trimHeaderFields : true,
            trimFieldValues  : true,
        };
        const csv_data = eol.auto(helpers.convertToUtf8(properties.content));
        if (properties.headers) {
            const result = JSON.parse(JSON.stringify(await converter.csv2jsonAsync(csv_data, options)));
            if(helpers.isObjectValid(result))
                return result;
            else
                throw Error(constants.ERROR_JSON_FORMAT);
        } else {
            const regex = new RegExp(`${properties.delimiter}(?=(?:[^\\"]*\\"[^\\"]*\\")*[^\\"]*$)`);
            const array = csv_data.toString().split(os.EOL);
            const customHeaders = [];
            let numHeaders = array[0].split(regex);
            for (let h in numHeaders) {
                customHeaders.push(`element ${Number.parseInt(h) + 1}`);
            }
            const csvToJsonResult = [];
            for (let i = 0; i < array.length; i++) {
                let obj = {};
                let currentLine = array[i].split(regex);
                for (let j = 0; j < customHeaders.length; j++) {
                    obj[customHeaders[j]] = currentLine[j];
                }
                csvToJsonResult.push(obj);
            }
            const result = JSON.parse(JSON.stringify(csvToJsonResult));
            if(helpers.isObjectValid(result))
                return result;
            else
                throw Error(constants.ERROR_JSON_FORMAT);
        }
    } catch (e) {
        throw Error(e);
    }
};

module.exports = {transformCsvToJson, transformJsonToCSV};
